abacusai.document_retriever_config — AbacusAI documentation

# abacusai.document_retriever_config

## Classes

`AbstractApiClass` |
`DocumentRetrieverConfig` | A config for document retriever creation.

## Module Contents

class abacusai.document_retriever_config.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.document_retriever_config.DocumentRetrieverConfig(client, chunkSize=None, chunkOverlapFraction=None, textEncoder=None, scoreMultiplierColumn=None, pruneVectors=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A config for document retriever creation.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - chunkSize (int) – The size of chunks for vector store, i.e., maximum number of words in the chunk.

    - chunkOverlapFraction (float) – The fraction of overlap between two consecutive chunks.

    - textEncoder (str) – The text encoder used to encode texts in the vector store.

    - scoreMultiplierColumn (str) – The values in this metadata column are used to modify the relevance scores of returned chunks.

    - pruneVectors (bool) – Corpus specific transformation of vectors that applies dimensional reduction techniques to strip common components from the vectors.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict